// TestCore.cpp : Test core functions of Wpio

#include "stdafx.h"

// -------------------------------------------------------------------------

void testFirst()
{
	WpioWriterPtr writer("Wpio.Writer");

	writer->NewWordDocfile(
		outputPath("testFirst.doc"), STGM_CREATE|STGM_READWRITE|STGM_SHARE_EXCLUSIVE);
	
	WpioDocument* doc = writer->Data;

	doc->NewNormalSection();
	doc->NewNormalParagraph();
	doc->NewNormalSpan();
	doc->AddText(L"Hello world!\x0d", 13);
	
	writer->Save();
}

AUTORUN(testFirst);

// -------------------------------------------------------------------------

void testSpanFormat()
{
	WpioWriterPtr writer("Wpio.Writer");

	writer->NewWordDocfile(
		outputPath("testSpanFormat.doc"), STGM_CREATE|STGM_READWRITE|STGM_SHARE_EXCLUSIVE);
	
	WpioDocument* doc = writer->Data;
	WpioFactory* fac = doc->Factory;

	WpioSpanFormat* span1 = fac->SpanFormat;
	span1->Bold = true;
	span1->Italic = true;

	WpioSpanFormat* span2 = fac->SpanFormat;

	doc->NewNormalSection();
	doc->NewNormalParagraph();
	doc->NewSpan(span1);
	doc->AddText(L"Hello ", 6);
	doc->NewSpan(span2);
	doc->AddText(L"world!\x0d", 7);
	
	writer->Save();
}

AUTORUN(testSpanFormat);

// -------------------------------------------------------------------------

void testParagraphFormat()
{
	WpioWriterPtr writer("Wpio.Writer");

	writer->NewWordDocfile(
		outputPath("testParagraphFormat.doc"), STGM_CREATE|STGM_READWRITE|STGM_SHARE_EXCLUSIVE);
	
	WpioDocument* doc = writer->Data;
	WpioFactory* fac = doc->Factory;

	WpioParagraphFormat* para1 = fac->ParagraphFormat;
	para1->CharacterUnitFirstLineIndent = 200;

	WpioParagraphFormat* para2 = fac->ParagraphFormat;

	WpioSpanFormat* span = fac->SpanFormat;

	doc->NewNormalSection();
	
	doc->NewParagraph(para1);
	doc->NewSpan(span);
	doc->AddText(L"Hello\x0d", 6);
	
	doc->NewParagraph(para2);
	doc->NewSpan(span);
	doc->AddText(L"world!\x0d", 7);
	
	writer->Save();
}

AUTORUN(testParagraphFormat);

// -------------------------------------------------------------------------

void testSectionFormat()
{
	WpioWriterPtr writer("Wpio.Writer");

	writer->NewWordDocfile(
		outputPath("testSectionFormat.doc"), STGM_CREATE|STGM_READWRITE|STGM_SHARE_EXCLUSIVE);
	
	WpioDocument* doc = writer->Data;
	WpioFactory* fac = doc->Factory;

	WpioSectionFormat* sect1 = fac->SectionFormat;
	sect1->Columns = 3;
	sect1->EvenlySpaced = TRUE;

	WpioSectionFormat* sect2 = fac->SectionFormat;

	doc->NewSection(sect1);
	
	doc->NewNormalParagraph();
	doc->NewNormalSpan();
	for (int i = 0; i < 10; ++i)
		doc->AddText(L"Hello ", 6);
	doc->AddChar(0x0d);

	doc->NewSection(sect2);
	
	doc->NewNormalParagraph();
	doc->NewNormalSpan();
	doc->AddText(L"world!\x0d", 7);
	
	writer->Save();
}

AUTORUN(testSectionFormat);

// -------------------------------------------------------------------------
